@@ -3,9 +3,10 @@ from importlib.metadata import version
 # Get the version
 __version__ = version(__name__)
 
-from .modules import SeaDexRadarr, SeaDexSonarr, setup_logger
+from .modules import seadexarr_cli, SeaDexRadarr, SeaDexSonarr, setup_logger
 
 __all__ = [
+    "seadexarr_cli",
     "SeaDexRadarr",
     "SeaDexSonarr",
     "setup_logger",
