@@ -1,8 +1,10 @@
+from .cli import seadexarr_cli
 from .seadex_radarr import SeaDexRadarr
 from .seadex_sonarr import SeaDexSonarr
 from .log import setup_logger
 
 __all__ = [
+    "seadexarr_cli",
     "SeaDexRadarr",
     "SeaDexSonarr",
     "setup_logger",
