@@ -4,6 +4,7 @@ import os
 import shutil
 from datetime import datetime
 from hashlib import md5
+from itertools import compress
 from urllib.request import urlretrieve
 from xml.etree import ElementTree
 
@@ -40,7 +41,6 @@ def save_json(
     if sort_cache:
 
         for arr, arr_item in data["anilist_entries"].items():
-
             keys = list(arr_item.keys())
             keys.sort(key=int)
             sorted_data = {key: arr_item[key] for key in keys}
@@ -57,6 +57,7 @@ def save_json(
 
 ANIME_IDS_URL = "https://raw.githubusercontent.com/Kometa-Team/Anime-IDs/refs/heads/master/anime_ids.json"
 ANIDB_MAPPINGS_URL = "https://raw.githubusercontent.com/Anime-Lists/anime-lists/refs/heads/master/anime-list-master.xml"
+ANIBRIDGE_MAPPINGS_URL = "https://raw.githubusercontent.com/eliasbenb/PlexAniBridge-Mappings/refs/heads/v2/mappings.json"
 
 ALLOWED_ARRS = [
     "radarr",
@@ -83,6 +84,62 @@ PRIVATE_TRACKERS = [
 UPDATED_AT_STR_FORMAT = "%Y-%m-%d %H:%M:%S"
 
 
+def get_all_seadex_rgs_per_episode(
+    seadex_dict,
+    ep_list,
+):
+    """Get a list of all SeaDex releases per-episode
+
+    Args:
+        seadex_dict: Dictionary of SeaDex releases
+        ep_list (list): List of episodes and info
+    """
+
+    all_seadex_rgs_per_episode = {"all": []}
+
+    if len(seadex_dict) > 1:
+        for seadex_rg, seadex_rg_item in seadex_dict.items():
+            seadex_urls = seadex_rg_item.get("urls", {})
+            for url, url_item in seadex_urls.items():
+
+                seadex_episodes = url_item.get("episodes", [])
+
+                # If we haven't managed to parse, then set this up as an
+                # "all" episodes fallback
+                if len(seadex_episodes) == 0:
+                    if seadex_rg not in all_seadex_rgs_per_episode.get(seadex_rg, []):
+                        all_seadex_rgs_per_episode["all"].append(seadex_rg)
+
+                found_episodes = [False] * len(seadex_episodes)
+
+                for seadex_idx, seadex_ep in enumerate(seadex_episodes):
+
+                    if found_episodes[seadex_idx]:
+                        continue
+
+                    for sonarr_ep in ep_list:
+                        sonarr_ep_season = sonarr_ep.get("seasonNumber", 999)
+                        sonarr_ep_episode = sonarr_ep.get("episodeNumber", 999)
+
+                        # Do we have a match?
+                        if sonarr_ep_season == seadex_ep.get(
+                            "season", 888
+                        ) and sonarr_ep_episode == seadex_ep.get("episode", 888):
+
+                            season_key = (
+                                f"S{sonarr_ep_season:02d}E{sonarr_ep_episode:02d}"
+                            )
+                            if season_key not in all_seadex_rgs_per_episode:
+                                all_seadex_rgs_per_episode[season_key] = []
+
+                            if seadex_rg not in all_seadex_rgs_per_episode[season_key]:
+                                all_seadex_rgs_per_episode[season_key].append(seadex_rg)
+
+                            found_episodes[seadex_idx] = True
+
+    return all_seadex_rgs_per_episode
+
+
 class SeaDexArr:
 
     def __init__(
@@ -147,6 +204,14 @@ class SeaDexArr:
 
             self.qbit = qbit
 
+        self.ignore_seadex_update_times = self.config.get(
+            "ignore_seadex_update_times", False
+        )
+
+        self.use_torrent_hash_to_filter = self.config.get(
+            "use_torrent_hash_to_filter", False
+        )
+
         # Hooks between torrents and Arrs, and torrent number bookkeeping
         self.torrent_category = self.config.get(f"{arr}_torrent_category", None)
         self.max_torrents_to_add = self.config.get("max_torrents_to_add", None)
@@ -178,13 +243,17 @@ class SeaDexArr:
         # Get the mapping files
         anime_mappings = self.config.get("anime_mappings", None)
         anidb_mappings = self.config.get("anidb_mappings", None)
+        anibridge_mappings = self.config.get("anibridge_mappings", None)
 
         if anime_mappings is None:
             anime_mappings = self.get_anime_mappings()
         if anidb_mappings is None:
             anidb_mappings = self.get_anidb_mappings()
+        if anibridge_mappings is None:
+            anibridge_mappings = self.get_anibridge_mappings()
         self.anime_mappings = anime_mappings
         self.anidb_mappings = anidb_mappings
+        self.anibridge_mappings = anibridge_mappings
 
         self.interactive = self.config.get("interactive", False)
 
@@ -209,11 +278,9 @@ class SeaDexArr:
             cache = self.setup_cache()
         self.cache = cache
 
-        # Check the package or config hasn't updated, else reset
-        # the cache
-        cache_updated = self.check_cache_updates()
-        if cache_updated:
-            self.cache = self.setup_cache()
+        # Check the package or config hasn't updated, else
+        # edit the cache description
+        self.check_cache_updates()
 
         self.log_line_sep = "="
         self.log_line_length = 80
@@ -273,11 +340,14 @@ class SeaDexArr:
         return cache
 
     def check_cache_updates(self):
-        """Check if anything's been updated to reset the cache"""
+        """Check if anything's been updated, and if so update in cache"""
 
         # Check if SeaDexArr version has updated
-        if self.cache.get("description", {}).get("seadexarr_version", None) != __version__:
-            return True
+        if (
+            self.cache.get("description", {}).get("seadexarr_version", None)
+            != __version__
+        ):
+            self.cache["description"]["seadexarr_version"] = __version__
 
         # Check if the config file has changed
         with open(self.config_file, "rb") as f:
@@ -286,9 +356,9 @@ class SeaDexArr:
                 self.cache.get("description", {}).get("config_checksum", None)
                 != config_hash
             ):
-                return True
+                self.cache["description"]["config_checksum"] = config_hash
 
-        return False
+        return True
 
     def get_anime_mappings(self):
         """Get the anime IDs file"""
@@ -321,6 +391,22 @@ class SeaDexArr:
 
         return anidb_mappings
 
+    def get_anibridge_mappings(self):
+        """Get PlexAniBridge mappings file"""
+
+        anibridge_mappings_file = os.path.join("anibridge_mappings.json")
+
+        # If a file doesn't exist, get it
+        self.get_external_mappings(
+            f=anibridge_mappings_file,
+            url=ANIBRIDGE_MAPPINGS_URL,
+        )
+
+        with open(anibridge_mappings_file, "r") as f:
+            anibridge_mappings = json.load(f)
+
+        return anibridge_mappings
+
     def get_external_mappings(
         self,
         f,
@@ -422,42 +508,159 @@ class SeaDexArr:
             )
 
         anilist_mappings = {}
+
+        # Start by looking through our base case, which are the Kometa
+        # Anime IDs. Save these to a dict where the key is the AniList ID
+        anilist_mappings = self.get_mappings_from_anime_mappings(
+            tvdb_id=tvdb_id,
+            tmdb_id=tmdb_id,
+            imdb_id=imdb_id,
+            tmdb_type=tmdb_type,
+            anilist_mappings=anilist_mappings,
+        )
+
+        # Then, look through the AniBridge mappings
+        anilist_mappings = self.get_mappings_from_anibridge_mappings(
+            tvdb_id=tvdb_id,
+            tmdb_id=tmdb_id,
+            imdb_id=imdb_id,
+            tmdb_type=tmdb_type,
+            anilist_mappings=anilist_mappings,
+        )
+
+        # Sort by AniList ID
+        anilist_mappings = dict(sorted(anilist_mappings.items()))
+
+        return anilist_mappings
+
+    def get_mappings_from_anime_mappings(
+        self,
+        tvdb_id=None,
+        tmdb_id=None,
+        imdb_id=None,
+        tmdb_type="movie",
+        anilist_mappings=None,
+    ):
+        """Get mappings from the Anime ID mappings
+
+        Args:
+            tvdb_id (int): TVDB ID
+            tmdb_id (int): TMDB ID
+            imdb_id (int): IMDb ID
+            tmdb_type (str): TMDB type. Can be "movie" or "show"
+            anilist_mappings (dict): Dictionary of AniList mappings.
+                Defaults to None, which will create a new dictionary
+        """
+
+        if anilist_mappings is None:
+            anilist_mappings = {}
+
+        if tmdb_type not in ["movie", "show"]:
+            raise ValueError("tmdb_type must be 'movie' or 'show'")
+
+        # Check we have exactly one ID specified here
+        non_none_sum = sum(v is not None for v in [tvdb_id, tmdb_id, imdb_id])
+
+        if non_none_sum == 0:
+            raise ValueError(
+                "At least one of tvdb_id, tmdb_id, and imdb_id must be provided"
+            )
+
         if tvdb_id is not None:
             anilist_mappings.update(
                 {
-                    n: m
+                    m["anilist_id"]: m
                     for n, m in self.anime_mappings.items()
                     if m.get("tvdb_id", None) == tvdb_id
+                    and m.get("anilist_id", None) is not None
+                    and m.get("anilist_id", None) not in anilist_mappings
                 }
             )
         if tmdb_id is not None:
             anilist_mappings.update(
                 {
-                    n: m
+                    m["anilist_id"]: m
                     for n, m in self.anime_mappings.items()
                     if m.get(f"tmdb_{tmdb_type}_id", None) == tmdb_id
+                    and m.get("anilist_id", None) is not None
+                    and m.get("anilist_id", None) not in anilist_mappings
                 }
             )
         if imdb_id is not None:
             anilist_mappings.update(
                 {
-                    n: m
+                    m["anilist_id"]: m
                     for n, m in self.anime_mappings.items()
                     if m.get("imdb_id", None) == imdb_id
+                    and m.get("anilist_id", None) is not None
+                    and m.get("anilist_id", None) not in anilist_mappings
                 }
             )
 
-        # Filter out anything without an AniList ID
-        anilist_mappings = {
-            n: m
-            for n, m in anilist_mappings.items()
-            if m.get("anilist_id", None) is not None
-        }
+        return anilist_mappings
 
-        # Sort by AniList ID
-        anilist_mappings = dict(
-            sorted(anilist_mappings.items(), key=lambda item: item[1].get("anilist_id"))
-        )
+    def get_mappings_from_anibridge_mappings(
+        self,
+        tvdb_id=None,
+        tmdb_id=None,
+        imdb_id=None,
+        tmdb_type="movie",
+        anilist_mappings=None,
+    ):
+        """Get mappings from the AniBridge mappings
+
+        Args:
+            tvdb_id (int): TVDB ID
+            tmdb_id (int): TMDB ID
+            imdb_id (int): IMDb ID
+            tmdb_type (str): TMDB type. Can be "movie" or "show"
+            anilist_mappings (dict): Dictionary of AniList mappings.
+                Defaults to None, which will create a new dictionary
+        """
+
+        if anilist_mappings is None:
+            anilist_mappings = {}
+
+        if tmdb_type not in ["movie", "show"]:
+            raise ValueError("tmdb_type must be 'movie' or 'show'")
+
+        # Check we have exactly one ID specified here
+        non_none_sum = sum(v is not None for v in [tvdb_id, tmdb_id, imdb_id])
+
+        if non_none_sum == 0:
+            raise ValueError(
+                "At least one of tvdb_id, tmdb_id, and imdb_id must be provided"
+            )
+
+        if tvdb_id is not None:
+            anilist_mappings.update(
+                {
+                    int(n): m
+                    for n, m in self.anibridge_mappings.items()
+                    if m.get("tvdb_id", None) == tvdb_id
+                    and int(n) not in anilist_mappings
+                }
+            )
+        if tmdb_id is not None:
+            anilist_mappings.update(
+                {
+                    int(n): m
+                    for n, m in self.anibridge_mappings.items()
+                    if m.get(f"tmdb_{tmdb_type}_id", None) == tmdb_id
+                    and m.get("anilist_id", None) is not None
+                    and int(n) not in anilist_mappings
+                }
+            )
+        if imdb_id is not None:
+            anilist_mappings.update(
+                {
+                    int(n): m
+                    for n, m in self.anibridge_mappings.items()
+                    if m.get("imdb_id", None) == imdb_id
+                    and m.get("anilist_id", None) is not None
+                    and int(n) not in anilist_mappings
+                }
+            )
 
         return anilist_mappings
 
@@ -542,10 +745,12 @@ class SeaDexArr:
             seadex_release_groups[t.release_group]["urls"][t.url] = {
                 "url": t.url,
                 "files": [f.name for f in t.files],
+                "size": [f.size for f in t.files],
                 "tracker": t.tracker,
                 "hash": t.infohash,
                 "download": False,
             }
+
         return seadex_release_groups
 
     def filter_seadex_interactive(
@@ -704,28 +909,137 @@ class SeaDexArr:
 
     def filter_seadex_downloads(
         self,
+        al_id,
         seadex_dict,
         arr,
-        arr_release_groups,
+        arr_release_dict,
         ep_list=None,
     ):
         """Flip the switch on whether we're downloading this torrent or not
 
         Args:
+            al_id: AniList ID
             seadex_dict: Dictionary of SeaDex releases
             arr: Type of arr instance
-            arr_release_groups: List of arr release groups
+            arr_release_dict: Dictionary of arr release properties
             ep_list: List of episodes. Defaults to None
         """
 
-        # If the release group is a string or a None, list it here
-        if isinstance(arr_release_groups, str) or arr_release_groups is None:
-            arr_release_groups = [arr_release_groups]
+        if self.use_torrent_hash_to_filter:
+            torrent_hashes, seadex_dict = self.filter_by_torrent_hash(
+                al_id=al_id,
+                seadex_dict=seadex_dict,
+                arr=arr,
+            )
+        else:
+            torrent_hashes, seadex_dict = self.filter_by_release_group(
+                seadex_dict=seadex_dict,
+                arr=arr,
+                arr_release_dict=arr_release_dict,
+                ep_list=ep_list,
+            )
 
-        # If we have overlaps, get a note of them here. Also
-        # set up an empty list for ones where we might not
-        # have managed to parse
-        all_seadex_rgs_per_episode = {"all": []}
+            # Also include any cached hashes
+            cached_hashes = (
+                self.cache.get("anilist_entries", {})
+                .get(arr, {})
+                .get(str(al_id), {})
+                .get("torrent_hashes", [])
+            )
+            torrent_hashes.extend(cached_hashes)
+
+        # Make sure the hashes are unique
+        torrent_hashes = list(set(torrent_hashes))
+
+        return torrent_hashes, seadex_dict
+
+    def filter_by_torrent_hash(
+        self,
+        al_id,
+        seadex_dict,
+        arr,
+    ):
+        """Select downloads if torrent hash is not already in cache
+
+        Note that for multiple "best" releases, this means everything will
+        be grabbed
+
+        Args:
+            al_id: AniList ID
+            seadex_dict: Dictionary of SeaDex releases
+            arr: Type of arr instance
+        """
+
+        cached_hashes = (
+            self.cache.get("anilist_entries", {})
+            .get(arr, {})
+            .get(str(al_id), {})
+            .get("torrent_hashes", [])
+        )
+        torrent_hashes = []
+
+        for seadex_rg, seadex_rg_item in seadex_dict.items():
+
+            self.logger.debug(
+                left_aligned_string(
+                    f"Filtering for release group {seadex_rg}",
+                    total_length=self.log_line_length,
+                )
+            )
+
+            seadex_urls = seadex_rg_item.get("urls", {})
+            for url, url_item in seadex_urls.items():
+
+                url_hash = url_item.get("hash", None)
+
+                # If the URL is already in the hash cache, then append but don't set to download
+                torrent_hashes.append(url_hash)
+                if url_hash not in cached_hashes:
+                    self.logger.debug(
+                        left_aligned_string(
+                            f"Torrent hash {url_hash} not found in cache. "
+                            f"Will add to downloads",
+                            total_length=self.log_line_length,
+                        )
+                    )
+
+                    url_item.update({"download": True})
+
+                else:
+                    self.logger.debug(
+                        left_aligned_string(
+                            f"Torrent hash {url_hash} in cache. " f"Will skip download",
+                            total_length=self.log_line_length,
+                        )
+                    )
+
+        return torrent_hashes, seadex_dict
+
+    def filter_by_release_group(
+        self,
+        seadex_dict,
+        arr,
+        arr_release_dict,
+        ep_list=None,
+    ):
+        """Filter torrents by release group
+
+        This is either episode-by-episode for the Sonarr
+        case where we can parse episodes, or a more blunt
+        hammer just checking against anything for Radarr
+        and weirdly named TV
+
+        Args:
+            seadex_dict: Dictionary of SeaDex releases
+            arr: Type of arr instance
+            arr_release_dict: Dictionary of arr release properties
+            ep_list: List of episodes. Defaults to None
+        """
+
+        # Get a simple list of the release groups
+        arr_release_groups = list(arr_release_dict.keys())
+
+        torrent_hashes = []
 
         # And also just check if any release group matches
         # any Arr release tag
@@ -739,57 +1053,25 @@ class SeaDexArr:
         if len(intersect) > 0:
             overlapping_results = True
 
-        if len(seadex_dict) > 1:
-            for seadex_rg, seadex_rg_item in seadex_dict.items():
-                seadex_urls = seadex_rg_item.get("urls", {})
-                for url, url_item in seadex_urls.items():
-
-                    seadex_episodes = url_item.get("episodes", [])
-
-                    # If we haven't managed to parse, then set this up as an
-                    # "all" episodes fallback
-                    if len(seadex_episodes) == 0:
-                        if seadex_rg not in all_seadex_rgs_per_episode.get(
-                            seadex_rg, []
-                        ):
-                            all_seadex_rgs_per_episode["all"].append(seadex_rg)
-
-                    found_episodes = [False] * len(seadex_episodes)
-
-                    for seadex_idx, seadex_ep in enumerate(seadex_episodes):
-
-                        if found_episodes[seadex_idx]:
-                            continue
-
-                        for sonarr_ep in ep_list:
-                            sonarr_ep_season = sonarr_ep.get("seasonNumber", 999)
-                            sonarr_ep_episode = sonarr_ep.get("episodeNumber", 999)
-
-                            # Do we have a match?
-                            if sonarr_ep_season == seadex_ep.get(
-                                "season", 888
-                            ) and sonarr_ep_episode == seadex_ep.get("episode", 888):
-
-                                season_key = (
-                                    f"S{sonarr_ep_season:02d}E{sonarr_ep_episode:02d}"
-                                )
-                                if season_key not in all_seadex_rgs_per_episode:
-                                    all_seadex_rgs_per_episode[season_key] = []
-
-                                if (
-                                    seadex_rg
-                                    not in all_seadex_rgs_per_episode[season_key]
-                                ):
-                                    all_seadex_rgs_per_episode[season_key].append(
-                                        seadex_rg
-                                    )
-
-                                found_episodes[seadex_idx] = True
+        # If we have overlaps, get a note of them here
+        all_seadex_rgs_per_episode = get_all_seadex_rgs_per_episode(
+            seadex_dict=seadex_dict,
+            ep_list=ep_list,
+        )
 
         for seadex_rg, seadex_rg_item in seadex_dict.items():
+
+            self.logger.debug(
+                left_aligned_string(
+                    f"Filtering for release group {seadex_rg}",
+                    total_length=self.log_line_length,
+                )
+            )
+
             seadex_urls = seadex_rg_item.get("urls", {})
             for url, url_item in seadex_urls.items():
 
+                url_hash = url_item.get("hash", None)
                 seadex_episodes = url_item.get("episodes", [])
 
                 # Simple case, we have no episode mappings so
@@ -806,6 +1088,47 @@ class SeaDexArr:
                         )
 
                         url_item.update({"download": True})
+                        torrent_hashes.append(url_hash)
+
+                    # Else, if we match then double-check against the size
+                    if seadex_rg in arr_release_groups:
+
+                        # Be a blunt hammer and just check intersections
+                        seadex_file_sizes = url_item.get("size", [])
+                        arr_file_sizes = arr_release_dict[seadex_rg].get("size", [])
+
+                        if not isinstance(arr_file_sizes, list):
+                            arr_file_sizes = [arr_file_sizes]
+
+                        intersect = list(
+                            filter(
+                                lambda x: x in seadex_file_sizes,
+                                arr_file_sizes,
+                            )
+                        )
+
+                        # If we have no overlaps at all, then add
+                        if len(intersect) == 0:
+                            self.logger.info(
+                                left_aligned_string(
+                                    f"SeaDex release group {seadex_rg} in {arr.capitalize()} release(s): "
+                                    f"{','.join([str(x) for x in arr_release_groups])}, but filesizes do not match. "
+                                    f"Will add {url} to downloads",
+                                    total_length=self.log_line_length,
+                                )
+                            )
+
+                            url_item.update({"download": True})
+                            torrent_hashes.append(url_hash)
+
+                        else:
+                            self.logger.debug(
+                                left_aligned_string(
+                                    f"SeaDex release group {seadex_rg} in {arr.capitalize()} release(s): "
+                                    f"{','.join([str(x) for x in arr_release_groups])}, and filesizes match. ",
+                                    total_length=self.log_line_length,
+                                )
+                            )
 
                 else:
 
@@ -815,10 +1138,14 @@ class SeaDexArr:
                             "If checking against individual episodes, you need to pass the Sonarr ep_list"
                         )
 
-                    # For each episode we've parsed from the torrent, check if a) it exists in the Sonarr list, and
-                    # if so, b) if the release group matches. If there's any mismatch at all, flip the switch to True
+                    # For each episode we've parsed from the torrent, check if a) it exists in the Sonarr list, b) if
+                    # the release group matches, and c) if the filesizes match. If there's any mismatch between release
+                    # groups (and there's no alternatives), then flip download to True. If all the sizes mismatch,
+                    # flip download to true
 
                     found_episodes = [False] * len(seadex_episodes)
+                    rg_matches = [False] * len(seadex_episodes)
+                    size_matches = [False] * len(seadex_episodes)
 
                     for seadex_idx, seadex_ep in enumerate(seadex_episodes):
 
@@ -827,13 +1154,25 @@ class SeaDexArr:
 
                         for sonarr_ep in ep_list:
 
+                            # Get Season, Episode, and size numbers for Sonarr and SeaDex
                             sonarr_ep_season = sonarr_ep.get("seasonNumber", 999)
                             sonarr_ep_episode = sonarr_ep.get("episodeNumber", 999)
+                            sonarr_ep_size = sonarr_ep.get("episodeFile", {}).get(
+                                "size", None
+                            )
+
+                            seadex_ep_season = seadex_ep.get("season", 888)
+                            seadex_ep_episode = seadex_ep.get("episode", 888)
+                            seadex_ep_size = seadex_ep.get("size", None)
 
                             # Do we have a match?
-                            if sonarr_ep_season == seadex_ep.get(
-                                "season", 888
-                            ) and sonarr_ep_episode == seadex_ep.get("episode", 888):
+                            if (
+                                sonarr_ep_season == seadex_ep_season
+                                and sonarr_ep_episode == seadex_ep_episode
+                            ):
+
+                                # Do the sizes match?
+                                size_match = sonarr_ep_size == seadex_ep_size
 
                                 season_ep_str = (
                                     f"S{sonarr_ep_season:02d}E{sonarr_ep_episode:02d}"
@@ -871,6 +1210,7 @@ class SeaDexArr:
                                         )
 
                                         url_item.update({"download": True})
+                                        torrent_hashes.append(url_hash)
 
                                 else:
 
@@ -881,10 +1221,44 @@ class SeaDexArr:
                                             total_length=self.log_line_length,
                                         )
                                     )
+                                    if not size_match:
+                                        self.logger.debug(
+                                            left_aligned_string(
+                                                f"-> Sizes are different: "
+                                                f"{sonarr_ep_size} (Sonarr), {seadex_ep_size} (SeaDex)",
+                                                total_length=self.log_line_length,
+                                            )
+                                        )
+                                    else:
+                                        self.logger.debug(
+                                            left_aligned_string(
+                                                f"-> Sizes match: {sonarr_ep_size}",
+                                                total_length=self.log_line_length,
+                                            )
+                                        )
+
+                                    rg_matches[seadex_idx] = True
+
+                                # Now check against file size
+                                if size_match:
+                                    size_matches[seadex_idx] = True
 
                                 found_episodes[seadex_idx] = True
 
-        return seadex_dict
+                    # If we have matched the release groups but not the file sizes, then flag that
+                    # here and mark for download
+                    size_matches = list(compress(size_matches, rg_matches))
+                    if not any(size_matches) and len(size_matches) > 0:
+                        self.logger.info(
+                            left_aligned_string(
+                                f"File sizes are all different for release group {seadex_rg}. "
+                                f"Will add {url} to downloads",
+                                total_length=self.log_line_length,
+                            )
+                        )
+                        url_item.update({"download": True})
+
+        return torrent_hashes, seadex_dict
 
     @staticmethod
     def get_any_to_download(seadex_dict):
