@@ -17,6 +17,16 @@ from .seadex_arr import SeaDexArr
 from .seadex_radarr import SeaDexRadarr
 
 
+TORRENT_FILENAMES_TO_SKIP = [
+    "NCED",
+    "NCOP",
+    "Creditless Ending",
+    "Creditless Opening",
+    "Creditless ED",
+    "Creditless OP",
+]
+
+
 def get_tvdb_id(mapping):
     """Get TVDB ID for a particular mapping
 
@@ -85,6 +95,95 @@ def get_overlapping_results(seadex_dict):
     return overlapping_results
 
 
+def check_ep_by_anime_ids(
+    ep,
+    tvdb_season,
+):
+    """Check whether to include an episode by Anime ID style
+
+    Args:
+        ep (dict): Dictionary of episode info
+        tvdb_season (int): TVDB season number
+    """
+
+    include_episode = True
+
+    # First, check by season
+    season_number = ep.get("seasonNumber", None)
+
+    # If the TVDB season is -1, this is anything but specials
+    if tvdb_season == -1 and season_number == 0:
+        include_episode = False
+
+    # Else, if we have a season defined, and it doesn't match, don't include
+    elif tvdb_season != -1 and season_number != tvdb_season:
+        include_episode = False
+
+    return include_episode
+
+
+def check_ep_by_anibridge(
+    ep,
+    tvdb_mappings,
+):
+    """Check whether to include an episode by AniBridge style
+
+    Args:
+        ep (dict): Dictionary of episode info
+        tvdb_mappings (dict): Dictionary of AniBridge-style TVDB mappings
+    """
+
+    ep_season = ep.get("seasonNumber", -1)
+    ep_episode = ep.get("episodeNumber", -1)
+
+    for season, episodes in tvdb_mappings.items():
+
+        tvdb_season = int(season.strip("s"))
+
+        # Simplest case, we have an empty string so just
+        # match by season
+        if episodes == "" and ep_season == tvdb_season:
+            return True
+
+        if ep_season != tvdb_season:
+            continue
+
+        # We may have multiple mappings per season,
+        # so we need to split
+        episodes_split = episodes.split(",")
+        for episode_split in episodes_split:
+
+            # There may be some ratio mapping that we
+            # can ignore
+            episode_split = episode_split.split("|")[0]
+
+            # The simpler case here is a single episode
+            if "-" not in episode_split:
+                episode_split_exact = int(episode_split.strip("e"))
+
+                if episode_split_exact == ep_episode:
+                    return True
+
+            # Or we need to split again, to get the start and
+            # end points
+            else:
+                episode_split_start_end = episode_split.split("-")
+                episode_split_start = int(episode_split_start_end[0].strip("e"))
+
+                # Now we might have an open-ended end point, in which case set to
+                # a large number
+                if len(episode_split_start_end) == 1:
+                    episode_split_end = 9999
+                else:
+                    episode_split_end = int(episode_split_start_end[1].strip("e"))
+
+                if episode_split_start <= ep_episode <= episode_split_end:
+                    return True
+
+    # If after all that, we haven't found anything, just return False
+    return False
+
+
 class SeaDexSonarr(SeaDexArr):
 
     def __init__(
@@ -187,10 +286,9 @@ class SeaDexSonarr(SeaDexArr):
                 self.log_no_anilist_mappings(title=sonarr_title)
                 continue
 
-            for anidb_id, mapping in al_mappings.items():
+            for al_id, mapping in al_mappings.items():
 
                 # Map the TVDB ID through to AniList
-                al_id = mapping.get("anilist_id", None)
                 if al_id is None:
                     self.log_no_anilist_id()
                     continue
@@ -209,7 +307,7 @@ class SeaDexSonarr(SeaDexArr):
                     seadex_entry=sd_entry,
                 )
 
-                if al_id_in_cache:
+                if al_id_in_cache and not self.ignore_seadex_update_times:
                     self.logger.info(
                         centred_string(
                             f"Cache time for AniList ID {al_id} matches SeaDex updated time",
@@ -225,7 +323,7 @@ class SeaDexSonarr(SeaDexArr):
                     continue
 
                 # Also check if it's in the Radarr cache, if we have that option
-                if self.ignore_movies_in_radarr:
+                if self.ignore_movies_in_radarr and not self.ignore_seadex_update_times:
                     al_id_in_radarr_cache = self.check_al_id_in_cache(
                         arr="radarr",
                         al_id=al_id,
@@ -253,6 +351,13 @@ class SeaDexSonarr(SeaDexArr):
                     sd_entry=sd_entry,
                 )
 
+                # Setup info for cache
+                cache_details = {
+                    "name": anilist_title,
+                    "updated_at": sd_entry.updated_at,
+                    "torrent_hashes": [],
+                }
+
                 # If we have a Radarr instance, and we don't want to add movies that
                 # are already in Radarr, do that now
                 if (
@@ -312,7 +417,7 @@ class SeaDexSonarr(SeaDexArr):
                 # Get the episode list for all relevant episodes
                 ep_list = self.get_ep_list(
                     sonarr_series_id=sonarr_series_id,
-                    anidb_id=anidb_id,
+                    al_id=al_id,
                     mapping=mapping,
                 )
 
@@ -326,11 +431,12 @@ class SeaDexSonarr(SeaDexArr):
                     time.sleep(self.sleep_time)
                     continue
 
-                sonarr_release_groups = self.get_sonarr_release_groups(ep_list=ep_list)
+                sonarr_release_dict = self.get_sonarr_release_dict(ep_list=ep_list)
+                sonarr_release_groups = list(sonarr_release_dict.keys())
 
                 self.logger.debug(
                     centred_string(
-                        f"Sonarr: {', '.join(sonarr_release_groups)}",
+                        f"Sonarr release group(s): {', '.join(sonarr_release_groups)}",
                         total_length=self.log_line_length,
                     )
                 )
@@ -340,6 +446,13 @@ class SeaDexSonarr(SeaDexArr):
 
                 if len(seadex_dict) == 0:
                     self.log_no_seadex_releases()
+
+                    self.update_cache(
+                        arr="sonarr",
+                        al_id=al_id,
+                        cache_details=cache_details,
+                    )
+
                     time.sleep(self.sleep_time)
                     continue
 
@@ -363,10 +476,11 @@ class SeaDexSonarr(SeaDexArr):
 
                 # Filter downloads by whether the episodes in each torrent match the release
                 # group we have in Sonarr
-                seadex_dict = self.filter_seadex_downloads(
+                torrent_hashes, seadex_dict = self.filter_seadex_downloads(
+                    al_id=al_id,
                     seadex_dict=seadex_dict,
                     arr="sonarr",
-                    arr_release_groups=sonarr_release_groups,
+                    arr_release_dict=sonarr_release_dict,
                     ep_list=ep_list,
                 )
 
@@ -428,11 +542,7 @@ class SeaDexSonarr(SeaDexArr):
                     )
 
                 # Update and save out the cache
-                cache_details = {
-                    "name": anilist_title,
-                    "updated_at": sd_entry.updated_at,
-                }
-
+                cache_details.update({"torrent_hashes": torrent_hashes})
                 self.update_cache(
                     arr="sonarr",
                     al_id=al_id,
@@ -517,24 +627,34 @@ class SeaDexSonarr(SeaDexArr):
     def get_ep_list(
         self,
         sonarr_series_id,
-        anidb_id,
+        al_id,
         mapping,
     ):
         """Get a list of relevant episodes for an AniList mapping
 
         Args:
             sonarr_series_id (int): Series ID in Sonarr
-            anidb_id (int): AniDB ID
+            al_id (int): Anilist ID
             mapping (dict): Mapping dictionary between TVDB and AniList
         """
 
         # If we have any season info, pull that out now
         tvdb_season = get_tvdb_season(mapping)
-        al_id = mapping.get("anilist_id", -1)
 
+        # Check we have a sensible AL ID
         if al_id == -1:
             raise ValueError("AniList ID not defined!")
 
+        # Get the AniDB ID
+        anidb_id = mapping.get("anidb_id", None)
+
+        # Check what kind of mode we're in here,
+        # it's either AniBridge or Anime IDs
+        if "tvdb_mappings" in mapping:
+            mapping_mode = "anibridge"
+        else:
+            mapping_mode = "anime_ids"
+
         # Get all the episodes for a season. Use the raw Sonarr API
         # call here to get details
         eps_req_url = (
@@ -561,18 +681,19 @@ class SeaDexSonarr(SeaDexArr):
         final_ep_list = []
         for ep in ep_list:
 
-            include_episode = True
-
-            # First, check by season
-            season_number = ep.get("seasonNumber", None)
-
-            # If the TVDB season is -1, this is anything but specials
-            if tvdb_season == -1 and season_number == 0:
-                include_episode = False
-
-            # Else, if we have a season defined, and it doesn't match, don't include
-            elif tvdb_season != -1 and season_number != tvdb_season:
-                include_episode = False
+            if mapping_mode == "anime_ids":
+                include_episode = check_ep_by_anime_ids(
+                    ep=ep,
+                    tvdb_season=tvdb_season,
+                )
+            elif mapping_mode == "anibridge":
+                tvdb_mappings = mapping.get("tvdb_mappings", {})
+                include_episode = check_ep_by_anibridge(
+                    ep=ep,
+                    tvdb_mappings=tvdb_mappings,
+                )
+            else:
+                raise ValueError(f"Invalid mapping mode {mapping_mode}")
 
             # If we've passed the vibe check, include things now
             if include_episode:
@@ -589,7 +710,7 @@ class SeaDexSonarr(SeaDexArr):
         # be for anything not marked as TV, and specials as marked by
         # being in Season 0
         anidb_mapping_dict = {}
-        if al_format not in ["TV"] or tvdb_season == 0:
+        if al_format not in ["TV"] or tvdb_season == 0 and anidb_id is not None:
             anidb_item = self.anidb_mappings.findall(f"anime[@anidbid='{anidb_id}']")
 
             # If we don't find anything, no worries. If we find multiple, worries
@@ -647,35 +768,45 @@ class SeaDexSonarr(SeaDexArr):
 
         else:
 
-            # Slice the list to get the correct episodes, so any potential offsets
-            ep_offset = mapping.get("tvdb_epoffset", 0)
-            n_eps, self.al_cache = get_anilist_n_eps(
-                al_id,
-                al_cache=self.al_cache,
-            )
+            # First case, we've got Anime IDs
+            if mapping_mode == "anime_ids":
 
-            # If we don't get a number of episodes, use them all
-            if n_eps is None:
-                n_eps = len(final_ep_list) - ep_offset
+                # Slice the list to get the correct episodes, so any potential offsets
+                ep_offset = mapping.get("tvdb_epoffset", 0)
+                n_eps, self.al_cache = get_anilist_n_eps(
+                    al_id,
+                    al_cache=self.al_cache,
+                )
+
+                # If we don't get a number of episodes, use them all
+                if n_eps is None:
+                    n_eps = len(final_ep_list) - ep_offset
+
+                # Check that we're including this by the episode number. This only
+                # works for single-seasons, so be careful!
+                if tvdb_season != -1:
+                    final_ep_list = [
+                        ep
+                        for ep in final_ep_list
+                        if 1 <= ep.get("episodeNumber", None) - ep_offset <= n_eps
+                    ]
+                else:
+                    final_ep_list = final_ep_list[ep_offset : n_eps + ep_offset]
+
+            # Or, we've got AniBridge mappings so we don't need to do anything (hooray)
+            elif mapping_mode == "anibridge":
+                pass
 
-            # Check that we're including this by the episode number. This only
-            # works for single-seasons, so be careful!
-            if tvdb_season != -1:
-                final_ep_list = [
-                    ep
-                    for ep in final_ep_list
-                    if 1 <= ep.get("episodeNumber", None) - ep_offset <= n_eps
-                ]
             else:
-                final_ep_list = final_ep_list[ep_offset: n_eps + ep_offset]
+                raise ValueError(f"Invalid mapping mode {mapping_mode}")
 
         return final_ep_list
 
-    def get_sonarr_release_groups(
+    def get_sonarr_release_dict(
         self,
         ep_list,
     ):
-        """Get a unique list of release groups for a series in Sonarr
+        """Get a dictionary of useful info for a series in Sonarr
 
         Args:
             ep_list (list): List of episodes
@@ -683,7 +814,7 @@ class SeaDexSonarr(SeaDexArr):
 
         # Look through, get release groups from the existing Sonarr files
         # and note any potential missing files
-        sonarr_release_groups = []
+        sonarr_release_dict = {}
         missing_eps = 0
         n_eps = len(ep_list)
         for ep in ep_list:
@@ -697,8 +828,10 @@ class SeaDexSonarr(SeaDexArr):
             if release_group is None or release_group == "":
                 continue
 
-            if release_group not in sonarr_release_groups:
-                sonarr_release_groups.append(release_group)
+            if release_group not in sonarr_release_dict:
+                sonarr_release_dict[release_group] = {"size": []}
+            size = ep.get("episodeFile", {}).get("size", None)
+            sonarr_release_dict[release_group]["size"].append(size)
 
         if missing_eps > 0:
             self.logger.info(
@@ -708,9 +841,7 @@ class SeaDexSonarr(SeaDexArr):
                 )
             )
 
-        sonarr_release_groups.sort()
-
-        return sonarr_release_groups
+        return sonarr_release_dict
 
     def parse_episodes_from_seadex(
         self,
@@ -734,13 +865,18 @@ class SeaDexSonarr(SeaDexArr):
 
                 # Set up a list to parse episodes from files
                 url_item.update({"episodes": []})
+                sizes = url_item.get("size", [])
 
-                for seadex_file in url_item.get("files", []):
+                for sd_file_idx, seadex_file in enumerate(url_item.get("files", [])):
 
                     # Get basename from the file, and encode it through for the API
                     # query
                     f = os.path.basename(seadex_file)
 
+                    # Skip filenames with things like "NCED", "NCOP"
+                    if any([x in f for x in TORRENT_FILENAMES_TO_SKIP]):
+                        continue
+
                     d = {"title": f, "apikey": self.sonarr_api_key}
                     d_enc = urlencode(d)
 
@@ -764,6 +900,7 @@ class SeaDexSonarr(SeaDexArr):
 
                         season = ep.get("seasonNumber", None)
                         episode = ep.get("episodeNumber", None)
+                        size = sizes[sd_file_idx]
 
                         if season is None or episode is None:
                             raise ValueError("Season or episode has come up None")
@@ -775,10 +912,18 @@ class SeaDexSonarr(SeaDexArr):
                         )
 
                         url_item["episodes"].append(
-                            {"season": season, "episode": episode}
+                            {
+                                "season": season,
+                                "episode": episode,
+                                "size": size,
+                            }
                         )
                         release_group_item["all_episodes"].append(
-                            {"season": season, "episode": episode}
+                            {
+                                "season": season,
+                                "episode": episode,
+                                "size": size,
+                            }
                         )
 
         return seadex_dict
